<?php

class File {
  function __construct($path) {
    $this->path = $path;
  }
  function name() {
    $pathParts = explode('/', $this->path);
    return array_pop($pathParts) . ($this->is_dir() ? '/' : '');
  }

  function contents() { return file_get_contents($this->path); }
  function is_dir() { return is_dir($this->path); }
}

class Dir {
  function __construct($path) {
    $this->path = $path;
  }
  function files() {
    $filenames = $foldernames = array();
    $handle = opendir($this->path);
    while (false != ($file = readdir($handle))) {
      if ($file[0] != '.') {
        if (is_dir($this->path . '/' . $file)) $foldernames[] = $file;
        else $filenames[] = $file;
      }
    }
    natcasesort($foldernames);
    natcasesort($filenames);
    $filenames = array_merge($foldernames, $filenames);
    $files = array();
    foreach ($filenames as $file)
      $files[] = new File($this->path . '/' . $file);
    closedir($handle);
    return $files;
  }
}

// helpers
function url_parts($path) {
  $parts = explode('/', $path);
  $return = array();
  foreach ($parts as $name)
    if ($name)
      $return[] = $name;
  return $return;
}
function fancyPath($folders) {
  $fancyTitle = '';
  $link = '/';
  foreach ($folders as $folder) {
    $link .= $folder . '/';
    $fancyTitle .= '/<a href="'.h($link).'" class="top">'.h($folder).'</a>';
  }
  return $fancyTitle;
}
function h($t) {
    return htmlspecialchars($t);
}
/*unhtmlspecialchars($string)
{
    $string = str_replace('&amp;', '&', $string);
    $string = str_replace('&#039;', '\'', $string);
    $string = str_replace('&quot;', '\"', $string);
    $string = str_replace('&lt;', '<', $string);
    $string = str_replace('&gt;', '>', $string);
   
    return $string;
}*/
function startswith($hay, $needle) {
    return $needle === $hay or strpos($hay, $needle) === 0;
}
function endswith($hay, $needle) {
    return $needle === $hay or strpos(strrev($hay), strrev($needle)) === 0;
}

$dir = false;
$file = false;

$title = 'Könyvtárak';

$page = urldecode($_SERVER['REQUEST_URI']);
$urlParts = url_parts($page);
$rootLink = empty($urlParts) ? $title . ' ' : '<a href="/" class="top">' . str_replace('127.0.0.1', $title, h($_SERVER['HTTP_HOST'])) . '</a>';
$pageName = array_pop($urlParts);
$path = $_SERVER['DOCUMENT_ROOT'];

// file
if ($pageName[0] == '?') {
  $pageName = substr($pageName, 1);
  $path .= implode('/', $urlParts) . '/' . $pageName;
  $file = is_file($path) ? new File($path) : false;
// dir
} else {
  $path .= $page;
  $dir = is_dir($path) ? new Dir($path) : false;
}

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-type" content="text/html; charset=utf-8" />
<meta id="viewport" name="viewport" content="width=device-width; initial-scale=1.0; maximum-scale=1.0; user-scalable=0;" />
<title>
<?php if ($pageName == null) { echo $title; } else { echo h($pageName); } ?>
</title>
<link rel="stylesheet" href="/.dirlist/iphonedirlist.css" type="text/css" />
<link rel="apple-touch-icon" href="/.dirlist/apple-touch-icon.png" />
</head>
<body onload="setTimeout(scrollTo, 0, 0, 1)">

<?php if ($_GET["debug"] == 'true') { ?>
<h3><u><font color='red'>DEBUG MODE</font></u></h3>
<br><i>script written by -V-O-Y-A-G-E-R-, fixed by Kane Lai</i>
<p>
<br>
<?php echo '_SERVER[\'REQUEST_URI\']: ' . h($_SERVER['REQUEST_URI']); ?>
<br>
<?php echo 'page: ' . h($page); ?>
<br>
<?php echo 'urlParts: ' . h($urlParts[0] . ' | ' . $urlParts[1] . ' | ' . $urlParts[2] . ' | ' . $urlParts[3] . ' | ' . $urlParts[4] . ' | ' . $urlParts[5]); ?>
<br>
<?php echo 'rootLink: ' . h($rootLink); ?>
<br>
<?php echo 'pageName: ' . h($pageName); ?>
<br>
<?php echo 'path: ' . h($path); ?>
</p>
<?php } ?>

<h1><?php echo $rootLink.fancyPath($urlParts) . '/ ' . h($pageName); ?></h1>

<?php if ($dir) { ?>

    <ul>
    <?php foreach ($dir->files() as $file) : ?>
        <a href="<?php echo str_replace('#', '%23', h($file->name())) ?>">
        <li>
            <?php echo h($file->name()) ?>        
        </li>
        </a>
    <?php endforeach; ?>
    </ul>

<?php } else if ($file != false) { ?>
    
    <pre><?php echo h($file->contents()) ?></pre>

<?php } else { ?>
    
    <p>
    Error!
    </p>

<?php } ?>
</body>
</html>